Charm for IBM WebSphere eXtreme Scale (IBM WXS) 8.6.0 for Client Application

## Overview

The WebSphere eXtreme Scale licensed program is an elastic, scalable, in-memory data grid. The data grid dynamically caches, partitions, replicates, and manages application data and business logic across multiple servers. WebSphere eXtreme Scale performs massive volumes of transaction processing with high efficiency and linear scalability. With WebSphere eXtreme Scale, you can also get qualities of service such as transactional integrity, high availability, and predictable response times.
For details on IBM WebSphere eXtreme Scale, as well as information on purchasing, please visit: [Product Page] [wxs-product-page] and at the [Passport Advantage Site] [Passport]. More information available at the [IBM Knowledge Center] [IBM-WXS-Infocenter]

`IBM WebSphere eXtreme Scale Client Application`

This charm is using IBM Installation Manager to install IBM WebSphere eXtreme Scale Software. This charm is using ibm-im charm as as base layer to install Installation Manager tool.
This charm is a sub-ordinate charm. It supports two topologies, viz: Standard Topology and Mixed Topology.

In case of `Standard Topology`, the principal charm is `ubuntu devenv` charm.
In case of `Mixed Topology`, the principal charm is `ibm-was-nd-dm` charm.

## Prerequisites

This charm makes use of resources, a feature only available in Juju 2.0. During deploy or upgrade, you will need to specify the installable package(s)
required by this charm. Download your licensed IBM WebSphere eXtreme Scale packages from the [Product Page] [WXS-8.6.0-download].

### Packages for Ubuntu on AMD64 (x86_64):

IBM Installation Manager 1.8 (`agent.installer.linux.gtk.x86_64_1.8.3000.20150606_0047.zip`)

IBM WXS 8.6.0 (`WS_XSCALE_V8.6_MP_ML.zip`)

### Packages for Ubuntu on Power (ppc64le):

For Ubuntu on Power, both Base Package and Fixpack 7 or later version Packages required to install.

IBM Installation Manager 1.8 (`agent.installer.linux.gtk.ppc64le_1.8.3000.20150606_0047.zip`)

IBM WXS 8.6.0 (`WS_XSCALE_V8.6_MP_ML.zip`)

`Standard Topology` - IBM WXS 8.6.0.7 (`8.6.0-WS-WXS-Client-FP0000007.zip`) 

`Mixed Topology` - IBM WXS WAS 8.6.0.7 (`8.6.0-WS-WXS-WAS8-Client-FP0000007.zip`) 

## Usage

To use this charm, you must agree to the Terms of Use. You can view the full license for `IBM Installation Manager` and `IBM WebSphere eXtreme Scale` products by visiting the [im-license-info](http://www-03.ibm.com/software/sla/sladb.nsf/displaylis/39AFC1C1D485C4E085257E7300548B05?OpenDocument) and [wxs-license-info] [license-info] page.

Search for "IBM WebSphere eXtreme Scale" and choose the license that applies to the version you are using.


## Memory and Disk Requirements

Space requirements

    Approximately 1.1 GB of disk space to store the required downloadable parts
    Approximately 1.1 GB of disk space to unpack the parts
    Approximately 400 MB of disk space to install the product
    Approximately 100 MB of space in the tmp directory to run the installation program

WebSphere eXtreme Scale Client Server Charm requires 15 GB of root disk to download packages and install the IBM WebSphere eXtreme Scale Client Server Software. By default available root disk space is 8GB.

To request a larger root disk, run the following command:

	juju set-constraints root-disk=15G

### Deploy

1. Run the following commands to deploy this charm:

	`Standard Topology`	 Deploy the prinicipal charm:
	
		juju deploy cs:trusty/ubuntu-devenv
	
	`Mixed Topology` Deploy the prinicipal charm:
	
	    juju deploy ibm-was-nd-dm
	
2. Deploy WXS Client charm:
	
	On x86_64 :
	
		juju deploy ibm-wxs-client --resource ibm_im_installer=</path/to/ibm_im_installer.zip> --resource ibm_wxs_base_installer=</path/to/ibm_wxs_base_installer.zip> 
		
	On ppc64le :
	
		juju deploy ibm-wxs-client --resource ibm_im_installer=</path/to/ibm_im_installer.zip> --resource ibm_wxs_base_installer=</path/to/ibm_wxs_base_installer.zip> --resource ibm_wxs_fixpack_installer=</path/to/ibm_wxs_fixpack_installer.zip>

    **Note**: This charm requires acceptance of Terms of Use. When deploying from the Charm Store, these terms will be presented to you for your consideration.  
         To accept the terms:
    
        juju agree ibm-im/1 ibm-wxs/1
            			
3. Add relation with prinicipal charm 
	
	`Standard Topology`:
	
	    juju add-relation ubuntu-devenv ibm-wxs-client
	
	In the above deployment scenario,  `ubuntu-devenv` and `ibm-wxs-client` charms are related using `juju-info` interface. To know more about `juju-info` interface, click [here](https://github.com/juju-solutions/interface-juju-info)
	
	`Mixed Topology`:
		
	    juju add-relation ibm-was-nd-dm ibm-wxs-client
	
	In the above deployment scenario, `ibm-was-nd-dm` and `ibm-wxs-client` charms are related using the `was-nd` interface. 

4. To Expose the IBM WXS Client Service to public, run the following command:

		juju expose ibm-wxs-client


### Upgrade

Once deployed, user can upgrade the existing installation by installing fixpacks:

If user wants to upgrade existing installation of Installtion Manger, run the following command:

	juju attach ibm-wxs-client ibm_im_fixpack=</path/to/fixpack.zip>

To upgrade WXS Client installation:
	
	juju attach ibm-wxs-client ibm_wxs_fixpack_installer=</path/to/ibm_wxs_fixpack_installer.zip>
	

## Relating with IBM WXS Catalog and IBM WXS Container

`Standard Topology`:

Install IBM WXS Container and IBM WXS Catalog Charm. 

Here IBM WXS Client charm is related to IBM WXS Catalog charm. To add a relation, run the following command:

	juju add-relation ibm-wxs-catalog ibm-wxs-client
	
**Note** : Before adding relation between ibm-wxs-catalog, establish a relation between ibm-wxs-catalog and ibm-wxs-container as below to make Data Grid available for Client:
	
	juju add-relation ibm-wxs-catalog ibm-wxs-container

When IBM WXS Client charm is related to IBM WXS Catalog charm, user can use the WXS Grid from IBM WXS Client charm.

`Mixed Topology`:

Install IBM WXS Container and IBM WXS Catalog Charm.

After successful Installation of IBM WXS Client charm on ibm-was-nd-dm charm, use your web browser to see the WebSphere Application Server - Network Deployment admin console. The URLs for WAS ND admin console are:

	http://was-nd-host:9060/ibm/console 
	https://was-nd-host:9043/ibm/console
		
**Note** : Before adding relation between ibm-wxs-catalog, establish a relation between ibm-wxs-catalog and ibm-wxs-container as below to make Data Grid available for Client:
	
	juju add-relation ibm-wxs-catalog ibm-wxs-container

When IBM WXS Client charm is related to IBM WXS Catalog charm, user can use the WXS Grid from IBM WXS Client charm.
	

### Verification

After establishing relation with IBM WXS Catalog charm, user can access the data grid from .NET Client in case of Standard Topology. 

To remove the relation, run the following command:

	juju remove-relation ibm-wxs-catalog ibm-wxs-client

In case of Mixed Topology, user can access Data Grid from IBM WAS ND UI Console by deploying client applications. For sample client application deployment on WAS-ND, please refer [here] [Sample-Application-Deployment]

## IBM Installation Manager(IM) Information

(1) General Information
Details about IM available at [IBM Knowledge Center][Im-info].

(2) Download Information
Information on procuring IM product is available at the [Product Page][im-product-page]
and at the [Passport Advantage Site][passport].	

## IBM IBM WebSphere eXtreme Scale Information

(1) General Information 

Details about IBM WXS software available at [IBM Knowledge Center] [IBM-WXS-Infocenter].

Information on procuring WXS product is available at the [Passport Advantage site] [Passport]

(2) Download Information

Details about IBM WXS 8.6.0 download available [here] [WXS-8.6.0-download]

Information about installation of IBM WXS on 'x86_64' and 'ppc64le' based machine available [here] [WXS-Installation]  

More information about IBM IM Downloadable file and WAS Base Downloadable files available [here] [IBM-IM-more-info]

## Contact Information

For issues with this charm, please contact IBM Juju Support team <jujusupp@us.ibm.com>

<!-- Links -->

[IM-info]: http://www-01.ibm.com/support/knowledgecenter/SSDV2W/im_family_welcome.html

[im-product-page]: http://www-01.ibm.com/support/docview.wss?uid=swg27025142

[wxs-product-page]: https://www.ibm.com/support/knowledgecenter/SSTVLU_8.6.0/com.ibm.websphere.extremescale.doc/cxsprodoverview.html

[IBM-WXS-Infocenter]: https://www.ibm.com/support/knowledgecenter/en/SSTVLU_8.6.0/com.ibm.websphere.extremescale.doc/kc_welcome-xs.html

[WXS-8.6.0-download]: http://www-01.ibm.com/support/docview.wss?uid=swg24033719

[WXS-Installation]: https://www.ibm.com/support/knowledgecenter/SSTVLU_8.6.0/com.ibm.websphere.extremescale.doc/txsinstalling.html

[Passport]: http://www-01.ibm.com/software/passportadvantage/

[IBM-IM-more-info]: http://www-01.ibm.com/support/docview.wss?uid=swg24038380

[WXS-download-links]: https://www-947.ibm.com/support/entry/myportal/all_download_links/websphere/websphere_extreme_scale?productContext=-966955061

[WXS-Support-link]: https://support-pilot.podc.sl.edst.ibm.com/support/home/product/P838994E69185S66/WebSphere_eXtreme_Scale?redir=auto_overlay&redirURL=https:%2F%2Fwww-947.ibm.com%2Fsupport%2Fentry%2Fmyportal%2Fproduct%2Fwebsphere%2Fwebsphere_extreme_scale%3FproductContext%3D-966955061%26redir%3Dno

[license-info]: http://www-01.ibm.com/common/ssi/cgi-bin/ssialias?htmlfid=897/ENUS212-370&infotype=AN&subtype=CA&appname=wwwsearch#h2-tcx

[Sample-Application-Deployment]: https://www.ibm.com/developerworks/community/blogs/714470bb-75c8-4f99-8aca-766c0d55a21c/entry/websphere_extreme_scale_getting_started_with_websphere_application_server_sample5?lang=en
