#!/bin/bash
set -ex

source charms.reactive.sh

ARCHITECTURE=`uname -m`
IM_INSTALL_PATH=/opt/IBM/InstallationManager
WXS_INSTALL_PATH=/opt/ibm/WXS
private_address=`unit-get private-address`

#Check the System Arch
function check_arch() {
	#Check the architecture before installing the product
	if [ "$ARCHITECTURE" != "x86_64" -a "$ARCHITECTURE" != "ppc64le" ]; then
		juju-log "check_arch: Unsupported platform. IBM WXS installed with this Charm supports only on x86_64 or ppc64le platform."
		status-set blocked "IBM WXS Client: Platform not supported"
	 	exit 1
	fi
}

function find_topology() {
	if charms.reactive is_state 'wasnd-dm.connected'
	then
		juju-log "Topology: Mixed"
		set_state 'mixed-topology'
	else
		juju-log "Topology: Standard"
		set_state 'standard-topology'
	fi
}

#start wxs client service
function start_was_dmgr(){ 
	#start was-nd-dmgr
	set +e
	dmgr_running=`ps -ef | grep "[d]mgr" | grep $was_nd_dm_profileName | grep -v grep`
	set -e
	if [ -z "$dmgr_running" ]; then
		was_nd_dm_install_path=$1
		was_nd_dm_user=$2
		was_nd_dm_password=$3
		was_nd_dm_profileName=$4
		juju-log "start_was_dmgr: was_nd_dm_install_path: $was_nd_dm_install_path"
		juju-log "start_was_dmgr: was_nd_dm_user : $was_nd_dm_user"
		juju-log "start_was_dmgr: was_nd_dm_password : $was_nd_dm_password"
		juju-log "start_was_dmgr: was_nd_dm_profileName : $was_nd_dm_profileName"
		
		if ! $was_nd_dm_install_path/profiles/$was_nd_dm_profileName/bin/startManager.sh -username $was_nd_dm_user -password $was_nd_dm_password
		then
			juju-log "start_was_dmgr: Error while starting dmgr"
			status-set blocked "IBM WXS Client: while starting dmgr"
			exit 0
		else
			juju-log "start_was_dmgr: started successfully"
			status-set maintenance "IBM WXS Client: WAS-ND-DM started successfully"
			set_state 'ibm-wxs-was-client-dmgr.started'
		fi
	else
		juju-log "start_was_dmgr: dmgr is running"
		status-set maintenance "IBM WXS Client: WAS-ND-DM already running"
	fi
}

#stop was-nd-dm  
function stop_was_dmgr() {
#stop wxs client service
set +e
dmgr_running=`ps -aux | grep '[d]mgr' | grep $was_nd_dm_profileName | grep -v grep`
set -e
if [ ! -z "$dmgr_running" ]; then
	
	was_nd_dm_install_path=$1
        was_nd_dm_user=$2
        was_nd_dm_password=$3
        was_nd_dm_profileName=$4
				
	juju-log "stop_was_dmgr was_nd_dm_install_path : $was_nd_dm_install_path"
	juju-log "stop_was_dmgr was_nd_dm_user : $was_nd_dm_user"
	juju-log "stop_was_dmgr was_nd_dm_password : $was_nd_dm_password"
	juju-log "stop_was_dmgr was_nd_dm_profileName : $was_nd_dm_profileName"

	set +e
	$was_nd_dm_install_path/profiles/$was_nd_dm_profileName/bin/stopManager.sh -username $was_nd_dm_user -password $was_nd_dm_password
	set -e
	if [ $? != 0 ]; then
		juju-log "stop_was_dmgr: WAS-ND-DM: Error while stopping"
		status-set blocked "IBM WXS Client: Error while stopping dmgr"
		exit 1
	else
		juju-log "stop_was_dmgr: WAS-ND-DM stopped successfully"
		status-set maintenance "IBM WXS Client: WAS-ND-DM stopped successfully"
		remove_state 'ibm-wxs-was-client-dmgr.started'
	fi
else
	juju-log "stop_was_dmgr: WAS-ND-DM: not running"
	status-set maintenance "IBM WXS Client: WAS-ND-DM not running"
fi
}

#Install WXS Client base package
@when 'ibm-im.installed'
@when_not 'ibm-wxs-client.installed' 'ibm-wxs-client-base-ppc64le.extracted'
function install-wxs-client(){
	
	#check arch supported
	juju-log "install-wxs-client: calling check_arch function"
	check_arch
	#add ip address to /etc/hosts

	find_topology

	if charms.reactive is_state 'standard-topology'
	then
		#clean up WXS if any from previous installation	
		if [ -d $WXS_INSTALL_PATH ]; then
			rm -fr $WXS_INSTALL_PATH
			if [ -d $WXS_INSTALL_PATH ]; then
				juju-log "install-wxs-client: unable to clean up $WXS_INSTALL_PATH of previous installation"
				exit 0
			fi
		fi
	fi

	juju-log "install-wxs-client: Checking etc/hosts file."
	private_address=`unit-get private-address`
	juju-log "install-wxs-client: private_address : $private_address"
	cd /etc
	if grep -q "$private_address" hosts
	then
		juju-log "install-wxs-client: Host file already updated"
	else
		juju-log "install-wxs-client: Updating Host file"
		echo "$private_address `hostname`" >> /etc/hosts
	fi
	#check if downloaded package is present in ${CHARM_DIR}/../resources
	#get the installable WXS packages
	if [ -d $CHARM_DIR/../resources/WXS_BASE/ ]; then
		juju-log "install-wxs-client: Base Package Extracted already"
		status-set maintenance "IBM WXS Client: Base Package Extracted already"
	fi
	if [ ! -d $CHARM_DIR/../resources/WXS_BASE/ ]; then
		juju-log "install-wxs-client: fetching the ibm_wxs_base_installer resource"
		status-set maintenance "IBM WXS Client: fetching the ibm_wxs_base_installer resource"
		cfg_wxs_base_pkg_name=`resource-get 'ibm_wxs_base_installer' || echo unavailable`

		ibm_wxs_pkg_isempty=`file $cfg_wxs_base_pkg_name | { grep -q empty && echo "True"; } || echo "False"`
	
		if [ "$cfg_wxs_base_pkg_name" = "unavailable" ]; then
			juju-log "install-wxs-client: missing required ibm_wxs_base_installer resource"
			status-set blocked "IBM WXS Client: missing required ibm_wxs_base_installer resource"
			exit 0
		fi
		if [ "$ibm_wxs_pkg_isempty" = "True" ]; then
			juju-log "install-wxs-client: missing required ibm_wxs_base_installer resource, found empty packages"
			status-set blocked "IBM WXS Client: missing required ibm_wxs_base_installer resource, provide actual ibm_wxs_base_installer resources."
			exit 0 
		fi


		if [ -f $cfg_wxs_base_pkg_name ]; then
			ARCHIVE_DIR=`dirname $cfg_wxs_base_pkg_name`
			juju-log "install-wxs-client: extracting the ibm_wxs_base_installer resources"
			status-set maintenance "IBM WXS Client: extracting the ibm_wxs_base_installer resource"
			if [ ! -d $ARCHIVE_DIR/../WXS_BASE ]; then
				mkdir $ARCHIVE_DIR/../WXS_BASE
			fi
			if ! unzip ${cfg_wxs_base_pkg_name} -d ${ARCHIVE_DIR}/../WXS_BASE
			then
				juju-log "install-wxs-client: Unable to extract the WXS package content. Verify whether the package is corrupt."
				status-set blocked "IBM WXS Client: IBM WXS package is corrupt"
				rm -rf $ARCHIVE_DIR/../WXS_BASE 
				exit 0
			else
				juju-log "install-wxs-client: Extracting package"
				status-set maintenance "IBM WXS Client: extracting wxs package"
			fi
		fi
	fi

	if charms.reactive is_state 'wasnd-dm.ready'
	then
		was_nd_dm_install_path=$(relation_call --state=wasnd-dm.connected get_was_dm_install_path)|| true
		was_nd_dm_user=$(relation_call --state=wasnd-dm.connected get_dmgradminuser) || true
		was_nd_dm_password=$(relation_call --state=wasnd-dm.connected get_dmgrpwd) || true
		was_nd_dm_profileName=$(relation_call --state=wasnd-dm.connected get_was_dm_profile_name) || true

		#stop dmgr before installing wxs
		juju-log "install-wxs-client: stopping dmgr : calling stop_was_dmgr function"
		stop_was_dmgr $was_nd_dm_install_path $was_nd_dm_user $was_nd_dm_password $was_nd_dm_profileName
	fi

	#install_wxs_base
	juju-log "install-wxs-client: WXS Base Installation started"
	if [ "$ARCHITECTURE" == "x86_64" ];then
		if charms.reactive is_state 'wasnd-dm.connected'
		then
			if ! $IM_INSTALL_PATH/eclipse/tools/imcl install com.ibm.websphere.WXSCLIENT.was8.v86 -acceptLicense -installationDirectory $was_nd_dm_install_path -repositories ${CHARM_DIR}/../resources/WXS_BASE/WXS_8600
			then
				juju-log "install-wxs-client: Error while installing WXS Base"
				status-set blocked "IBM WXS Client: Error while installing WXS Base"
				exit 1
			else
				juju-log "install-wxs-client: WXS Base installed successfully"
				status-set maintenance "IBM WXS Client: WXS Base installed successfully"
				set_state 'ibm-wxs-client.installed'
			fi	
		else
			if ! $IM_INSTALL_PATH/eclipse/tools/imcl install com.ibm.websphere.WXSCLIENT.v86 -acceptLicense -installationDirectory $WXS_INSTALL_PATH -repositories ${CHARM_DIR}/../resources/WXS_BASE/WXS_8600
			then
				juju-log "install-wxs-client: Error while installing WXS Base"
				status-set blocked "IBM WXS Client: Error while installing WXS Base"
				exit 1
			else
				juju-log "install-wxs-client: WXS Base installed successfully"
				status-set maintenance "IBM WXS Client: WXS Base installed successfully"
				set_state 'ibm-wxs-client.installed'
			fi	
		fi
	elif [ "$ARCHITECTURE" == "ppc64le" ];then
		if [ -d ${CHARM_DIR}/../resources/WXS_BASE/WXS_8600 ]; then
			juju-log "install-wxs-client: Both WXS Package and Fixpack for PPC64LE"
			status-set blocked "IBM WXS Client: Both WXS Base and Fixpack are required to install on ppc64le"
			set_state 'ibm-wxs-client-base-ppc64le.extracted'
		fi	
	fi
}

#Install WXS Client fixpack package
@when_any 'ibm-wxs-client.installed' 'ibm-wxs-client-base-ppc64le.extracted'
@when_not 'ibm-wxs-client.updated'
function install-wxs-client-fixpack(){

	#get the installable WXS fixpack
	juju-log "install-wxs-client-fixpack: fetching the ibm_wxs_fixpack_installer resource"
	status-set maintenance "IBM WXS Client: fetching the ibm_wxs_fixpack_installer resource"
	cfg_wxs_fixpack_pkg_name=`resource-get 'ibm_wxs_fixpack_installer' || echo unavailable`

	ibm_wxs_fixpack_isempty=`file $cfg_wxs_fixpack_pkg_name | { grep -q empty && echo "True"; } || echo "False"`

	if [ "$cfg_wxs_fixpack_pkg_name" = "unavailable" ]; then
		if [ "$ARCHITECTURE" == "ppc64le" ]; then
			juju-log "install-wxs-client-fixpack: issing required ibm_wxs_fixpack_installer resource"
			status-set blocked "IBM WXS Client: missing required ibm_wxs_fixpack_installer resource for ppc64le platform"
			exit 0	
		elif [ "$ARCHITECTURE" == "x86_64" ]; then
			juju-log "install-wxs-client-fixpack: no ibm_wxs_fixpack_installer packages to install"
			status-set active "IBM WXS Client: IBM WXS Client is Ready"
			return 0
		fi
	fi
			
	if [ "$ibm_wxs_fixpack_isempty" = "True" ]; then
		if [ "$ARCHITECTURE" == "ppc64le" ]; then
			juju-log "install-wxs-client-fixpack: missing required ibm_wxs_fixpack_installer resource, found empty packages"
			status-set blocked "IBM WXS Client: missing required ibm_wxs_fixpack_installer resource, provide actual ibm_wxs_fixpack_installer resources."
			exit 0	
		elif [ "$ARCHITECTURE" == "x86_64" ]; then
			juju-log "install-wxs-client-fixpack: no ibm_wxs_fixpack_installer packages to install"
			status-set active "IBM WXS Client: IBM WXS Client is Ready"
			return 0
		fi
		
fi
if [ -f ${cfg_wxs_fixpack_pkg_name} ]; then
	juju-log "install-wxs-client-fixpack: extracting WXS fixpack packages"
		ARCHIVE_DIR=`dirname $cfg_wxs_fixpack_pkg_name`
		 juju-log "install-wxs-client-fixpack: extracting the ibm_was_fixpack_installer resource"
	 status-set maintenance "IBM WXS Client: extracting the ibm_was_fixpack_installer resources"

	if [ ! -d $ARCHIVE_DIR/../WXS_FP ]; then
		mkdir $ARCHIVE_DIR/../WXS_FP
	fi
	if ! unzip ${cfg_wxs_fixpack_pkg_name} -d ${ARCHIVE_DIR}/../WXS_FP
		then
		juju-log "install-wxs-client-fixpack: Unable to extract the WXS fixpack package content. Verify whether the package is corrupt."
		status-set blocked "IBM WXS Client: IBM WXS fixpack package is corrupt"
		rm -rf $ARCHIVE_DIR/../WXS_FP
		exit 0
	else
		juju-log "install-wxs-client-fixpack: Extracted WXS fixpack package"
		status-set maintenance "IBM WXS Client: Extracted wxs fixpack package"
	fi
fi
	if charms.reactive is_state 'wasnd-dm.ready'
	then
		was_nd_dm_install_path=$(relation_call --state=wasnd-dm.connected get_was_dm_install_path)|| true
		was_nd_dm_user=$(relation_call --state=wasnd-dm.connected get_dmgradminuser) || true
		was_nd_dm_password=$(relation_call --state=wasnd-dm.connected get_dmgrpwd) || true
		was_nd_dm_profileName=$(relation_call --state=wasnd-dm.connected get_was_dm_profile_name) || true
		
		#stop dmgr before installing wxs
		juju-log "install-wxs-client-fixpack: stopping dmgr : calling stop_was_dmgr function"
		stop_was_dmgr $was_nd_dm_install_path $was_nd_dm_user $was_nd_dm_password $was_nd_dm_profileName
	fi		
	#Install WXS fixpack package
	juju-log "install-wxs-client-fixpack: WXS Fix Pack Installation started"
	status-set maintenance "IBM WXS Client: WXS Fix Pack Installation started"
	if [ "$ARCHITECTURE" == "x86_64" ];then
		if charms.reactive is_state 'wasnd-dm.connected'
		then
			if ! $IM_INSTALL_PATH/eclipse/tools/imcl install com.ibm.websphere.WXSCLIENT.was8.v86 -acceptLicense -installationDirectory $was_nd_dm_install_path -repositories ${CHARM_DIR}/../resources/WXS_FP/ 
			then
				juju-log "install-wxs-client-fixpack: install_wxs_fixpack: Error while installing WXS Client Fix Pack"
				status-set blocked "IBM WXS Client: Error while upgrading WXS Fix Pack"
				exit 1
			else
				juju-log "install-wxs-client-fixpack: install_wxs_fixpack: WXS Client Fix Pack is installed successfully"
				status-set active "IBM WXS Client: WXS Fix Pack is installed successfully"
				set_state 'ibm-wxs-client.updated'
			fi	
		else
			if ! $IM_INSTALL_PATH/eclipse/tools/imcl install com.ibm.websphere.WXSCLIENT.v86 -acceptLicense -installationDirectory $WXS_INSTALL_PATH -repositories ${CHARM_DIR}/../resources/WXS_FP/ 
			then
				juju-log "install-wxs-client-fixpack: Error while installing WXS Fix Pack"
				status-set blocked "IBM WXS Client: Error while upgrading WXS Fix Pack"
				exit 1
			else
				juju-log "install-wxs-client-fixpack: WXS Fix Pack is installed successfully"
				status-set active "IBM WXS Client: WXS Fix Pack is installed successfully"
				set_state 'ibm-wxs-client.updated'
			fi
		fi
	elif [ "$ARCHITECTURE" == "ppc64le" ]; then
		if [ -d ${CHARM_DIR}/../resources/WXS_FP -a -d ${CHARM_DIR}/../resources/WXS_BASE/WXS_8600 ]; then
			if charms.reactive is_state 'wasnd-dm.connected' ; then
				if ! $IM_INSTALL_PATH/eclipse/tools/imcl install com.ibm.websphere.WXSCLIENT.was8.v86 -acceptLicense -installationDirectory $was_nd_dm_install_path -repositories ${CHARM_DIR}/../resources/WXS_FP/,${CHARM_DIR}/../resources/WXS_BASE/WXS_8600
				then
					juju-log "install-wxs-client-fixpack: Error while installing WXS Fix Pack"
					status-set blocked "IBM WXS Client: Error while Installing WXS Pack"
					exit 1
				else
					juju-log "install-wxs-client-fixpack: WXS Fix Pack is installed successfully"
					status-set active "IBM WXS Client: WXS installed successfully!"
					set_state 'ibm-wxs-client.installed'
					set_state 'ibm-wxs-client.updated'
				fi
			else
			
				if ! $IM_INSTALL_PATH/eclipse/tools/imcl install com.ibm.websphere.WXSCLIENT.v86 -acceptLicense -installationDirectory $WXS_INSTALL_PATH -repositories ${CHARM_DIR}/../resources/WXS_FP/,${CHARM_DIR}/../resources/WXS_BASE/WXS_8600
				then
					juju-log "install-wxs-client-fixpack: Error while installing WXS Fix Pack"
					status-set blocked "IBM WXS Client: Error while Installing WXS Pack"
					exit 1
				else
					juju-log "install-wxs-client-fixpack: WXS Fix Pack is installed successfully"
					status-set active "IBM WXS Client: WXS installed successfully!"
					set_state 'ibm-wxs-client.installed'
					set_state 'ibm-wxs-client.updated'
				fi
			fi
			
		else
				juju-log "install-wxs-client-fixpack: Get WXS Package and Fixpack Both for PPC64LE"
				status-set blocked "IBM WXS Client: WXS needs Both Base and Fix Packages to be installed on PPC64LE"
				exit 0
		fi
	fi
}

@when 'wasnd-dm.connected' 'wasnd-dm.ready'
@when_any 'ibm-wxs-client.installed' 'ibm-wxs-client.updated'
function start_was_nd_dmgr() {
	if ! charms.reactive is_state 'ibm-was-nd-dm.manager.started'; then
		was_nd_dm_install_path=$(relation_call --state=wasnd-dm.connected get_was_dm_install_path)|| true
		was_nd_dm_user=$(relation_call --state=wasnd-dm.connected get_dmgradminuser) || true
		was_nd_dm_password=$(relation_call --state=wasnd-dm.connected get_dmgrpwd) || true
		was_nd_dm_profileName=$(relation_call --state=wasnd-dm.connected get_was_dm_profile_name) || true
		start_was_dmgr $was_nd_dm_install_path $was_nd_dm_user $was_nd_dm_password $was_nd_dm_profileName
	fi
}

@hook 'upgrade-charm'
function check_fixpack(){
# The upgrade-charm hook will fire when a new resource is pushed for this
# charm. This is a good time to determine if we need to deal with a new
# fixpack.
	if ! charms.reactive is_state 'ibm-wxs-client.updated'; then
		# If there is no prior fixpack installed (because ibm-wxs-client.updated is not
		# set), do nothing since install_wxs_client_fixpack will handle that case.
		juju-log "check_fixpack: no fixpack has been installed; nothing to upgrade."
		return 0
	else
		# If we have a fixpack packges already (because ibm-wxs-client.updated is set),
		# we should fetch the latest fixpack packages and determine if it is new.
		#  - If it is new, set our states so install_wxs_client_fixpack is called again
		#  - If it is not new, do nothing
		juju-log "check_fixpack: scanning for new fixpacks to install"
		WXS_FP_DIR="$CHARM_DIR/../resources/ibm_wxs_fixpack_installer"
	       
		CUR_FP="$WXS_FP_DIR/ibm_wxs_fixpack_installer.zip"
	       
		if [ -f $CUR_FP ]; then
			CUR_FP_MD5=`md5sum "$CUR_FP" | awk '{print $1}'`
		fi
	     
		NEW_FP=`resource-get 'ibm_wxs_fixpack_installer' || echo unavailable`
	    
		if [ "$NEW_FP" = "unavailable" ]; then
			juju-log "check_fixpack: no fixpack to install"
			return 0
		elif [ -f $NEW_FP ]; then
			NEW_FP_MD5=`md5sum "$NEW_FP" | awk '{print $1}'`
		fi
	 
		if [ "$CUR_FP_MD5" != "$NEW_FP_MD5" ]; then
			juju-log "check_fixpack: new fixpack detected ($CUR_FP with $CUR_FP_MD5 versus $NEW_FP with $NEW_FP_MD5)"
			rm -rf $CHARM_DIR/../resources/WXS_FP
			remove_state 'ibm-wxs-client.updated'
		else
			juju-log "check_fixpack: no new fixpack to install"
		fi
	fi
}

@when 'wasnd-dm.departed' 'mixed-topology'
function uninstall_was_wxs() {

	was_nd_dm_install_path=$(relation_call --state=wasnd-dm.departed get_was_dm_install_path )|| true
	was_nd_dm_user=$(relation_call --state=wasnd-dm.departed get_dmgradminuser) || true
	was_nd_dm_password=$(relation_call --state=wasnd-dm.departed get_dmgrpwd) || true
	was_nd_dm_profileName=$(relation_call --state=wasnd-dm.departed get_was_dm_profile_name) || true
	juju-log "uninstall_was_wxs: The Values was_nd_dm_install_path=$was_nd_dm_install_path was_nd_dm_user=$was_nd_dm_user was_nd_dm_password=$was_nd_dm_password was_nd_dm_profileName=$was_nd_dm_profileName"
	
	juju-log "uninstall_was_wxs: Stopping WAS ND DM to Uninstall WXS Client"
	status-set maintenance "IBM WXS Client: Stopping WAS ND DM to Uninstall WXS Client"
	if [ ! -z $was_nd_dm_install_path -a ! -z $was_nd_dm_user -a ! -z $was_nd_dm_password -a ! -z $was_nd_dm_profileName ]
	then
		stop_was_dmgr $was_nd_dm_install_path $was_nd_dm_user $was_nd_dm_password $was_nd_dm_profileName
		juju-log "uninstall_was_wxs: Uninstalling WXS Client"
		if $IM_INSTALL_PATH/eclipse/tools/imcl uninstall com.ibm.websphere.WXSCLIENT.was8.v86 -installationDirectory $was_nd_dm_install_path
		then
			juju-log "uninstall_was_wxs: WXS Client on WAS : Uninstalled Successfully"
			status-set maintenance "IBM WXS Client: WXS Client on WAS: Uninstalled Successfully"
			juju-log "uninstall_was_wxs: Starting WAS ND DM after Uninstall WXS Client"
			status-set maintenance "IBM WXS Client: Stopping WAS ND DM to Uninstall WXS Client"
			start_was_dmgr $was_nd_dm_install_path $was_nd_dm_user $was_nd_dm_password $was_nd_dm_profileName
		else
			juju-log "uninstall_was_wxs: WXS Client on WAS : Error during Uninstallation"
			status-set maintenance "IBM WXS Client: WXS Client on WAS : Error during Uninstallation"
		fi
	else
		juju-log "uninstall_was_wxs: Can not proceed to uninstall WXS Client. No proper information"
		status-set maintenance "IBM WXS Client: WXS Client on WAS: Can not proceed to uninstall WXS Client. No proper information"
	fi
	
}

@when_not 'devenv.available'
@when 'standard-topology'
function uninstall_wxs() {
	juju-log "Uninstalling WXS Client"
	if [ -d $WXS_INSTALL_PATH ]; then
		if $IM_INSTALL_PATH/eclipse/tools/imcl uninstall com.ibm.websphere.WXSCLIENT.v86 -installationDirectory $WXS_INSTALL_PATH
		then
			juju-log "uninstall_wxs: WXS Client: Uninstalled Successfully"
		fi
	fi
}

@when_any 'ibm-wxs-client.installed' 'ibm-wxs-client.updated'
@when 'wxsgrid.available' 'wxsgrid.ready' 'standard-topology'
@when_not 'ibm-wxs-client.connected'
function test_connection() {
	juju-log "Checking Connection with Catalog"
	 if [ -d $WXS_INSTALL_PATH ]; then
		wxs_catalog_ip=$(relation_call --state=wxsgrid.available get_wxs_catalog_ip )|| true
		wxs_catalog_port=$(relation_call --state=wxsgrid.available get_wxs_catalog_port) || true
		
		#Update the $WXS_INSTALL_PATH/ObjectGrid/gettingstarted/env.sh file 
		# to update the Catalog server host
		juju-log "test_connection: Updating $WXS_INSTALL_PATH/ObjectGrid/gettingstarted/env.sh"
		envfile_server=`grep "CATALOGSERVER_HOST=" $WXS_INSTALL_PATH/ObjectGrid/gettingstarted/env.sh | awk -F"CATALOGSERVER_HOST=" '{print $2}'`
		set +e
		sudo sed -i -e "s|$envfile_server|$wxs_catalog_ip|g" $WXS_INSTALL_PATH/ObjectGrid/gettingstarted/env.sh
		set -e
		if [ $? == 0 ]; then
			juju-log "test_connection: Updated $WXS_INSTALL_PATH/ObjectGrid/gettingstarted/env.sh file with catalog server"
		else
			juju-log "test_connection: ERROR: While updating $WXS_INSTALL_PATH/ObjectGrid/gettingstarted/env.sh file with catalog server"
			exit 0
		fi
		juju-log "test_connection: Start Connection Checking"
		if $WXS_INSTALL_PATH/ObjectGrid/gettingstarted/runclient.sh g aaa | grep "Not found"
		then
			if $WXS_INSTALL_PATH/ObjectGrid/gettingstarted/runclient.sh i aaa bbb
			then
				juju-log "test_connection: Pushed the key value pair"
				value=`$WXS_INSTALL_PATH/ObjectGrid/gettingstarted/runclient.sh g aaa | grep "Value is TestValue" | grep "bbb"`
				if [ ! -z "$value" ];then
					juju-log "test_connection: Got the key value pair"
					set_state 'ibm-wxs-client.connected'
				else
					juju-log "test_connection: Failed to connect to catalog"
					exit 0
				fi
			else
				juju-log "test_connection: Failed to insert the value"
				exit 0
			fi
		
			juju-log "test_connection: Removing aaa bbb from catalog"
			if $WXS_INSTALL_PATH/ObjectGrid/gettingstarted/runclient.sh d aaa
			then
				juju-log "test_connection: Removed value aaa bbb"
			else	
				juju-log "test_connection: Could not remove value aaa. Remove Manually"
			fi
		else
			juju-log "test_connection: key pair value [aaa bbb] is already present"
			set_state 'ibm-wxs-client.connected'
			if $WXS_INSTALL_PATH/ObjectGrid/gettingstarted/runclient.sh d aaa
			then
				juju-log "test_connection: Removed value aaa bbb"
			else	
				juju-log "test_connection: Could not remove value aaa. Remove Manually"
			fi
		fi
	fi
}

@when 'ibm-wxs-client.connected' 'wxsgrid.available' 'standard-topology'
function display() {
	juju-log "display: WXSCLIENT has established the Conncetion with WXS Catalog $wxs_catalog_ip"
	status-set maintenance "IBM WXS Client: WXSCLIENT has established the Conncetion with WXS Catalog $wxs_catalog_ip"
}

@when_any 'ibm-wxs-client.installed' 'ibm-wxs-client.updated' 'standard-topology'
@when_not 'wxsgrid.available'
function remove_connection () {	
	juju-log "remove_connection: removing connection"
	remove_state 'ibm-wxs-client.connected'
	status-set maintenance "IBM WXS Client: Establish the connection with WXS Catalog"
}

reactive_handler_main
