#!/usr/bin/env python3

import unittest
import amulet
import re

class TestDeploy(unittest.TestCase):
    """ Create a class for testing the charm in the unit test framework. """
    @classmethod
    def setUpClass(self):
        """
        Trivial deployment test for IBM WXS Container Server.

        This charm cannot do anything useful by itself, it
        will deploy WXS Catalog , WXS Container and WXS Client
        and add a relation between catalog and container and allow
        /opt/ibm/WXS files to be shared. So integration testing
        is done in the bundle.
        """

        self.d = amulet.Deployment(series='trusty')

        self.d.add('ubuntu-devenv', 'cs:~charmers/trusty/ubuntu-devenv-0')
        self.d.add('ibm-wxs-catalog',
                   'cs:~ibmcharmers/trusty/ibm-wxs-catalog')
        self.d.add('ibm-wxs-container',
                   'cs:~ibmcharmers/trusty/ibm-wxs-container')
        self.d.add('ibm-wxs-client',
                   'cs:~ibmcharmers/trusty/ibm-wxs-client')
        self.d.relate('ubuntu-devenv:juju-info','ibm-wxs-client:devenv')
        self.d.relate('ibm-wxs-catalog:wxsgrid',
                      'ibm-wxs-container:wxsgrid')
        self.d.relate('ibm-wxs-catalog:wxsgrid',
                      'ibm-wxs-client:wxsgrid')
        self.d.setup(timeout=20000)
        self.d.sentry.wait(timeout=20000)

    def test_deploy_with_placeholder_resource(self):
        # The status message when using placeholder resources will include the
        # string "ibm_wxs_base_installer resource".
        # If we see that, the test is successful.
        sentry_re = re.compile('ibm_wxs_base_installer resource')
        self.d.sentry.wait_for_messages({"ibm-wxs-catalog":
                                        sentry_re})
        sentry_re = re.compile('ibm_wxs_base_installer resource')
        self.d.sentry.wait_for_messages({"ibm-wxs-container":
                                        sentry_re})
        sentry_re = re.compile('ibm_wxs_base_installer resource')
        self.d.sentry.wait_for_messages({"ibm-wxs-client":
                                        sentry_re})

    def test_unit_deployed(self):
        # verify unit
        self.assertTrue(self.d.deployed)
        unit_wxsclient_0 = self.d.sentry['ibm-wxs-client'][0]
        state_wxsclient = unit_wxsclient_0.info['agent-state']
        print('IBM WXS Client is %s' % state_wxscontainer)
        wxs_client_ip = unit_wxsclient_0.info['public-address']
        print('IBM WXS Client IP is %s' % wxs_client_ip)
        cmd = "cd /opt/ibm/WXS; pwd"
        output, code = unit_wxscontainer_0.run(cmd)
        if code != 0:
            message = 'IBM WXS Client is not installed correctly \
                      as WXS installation path does not exist'
            amulet.raise_status(amulet.FAIL, msg=message)
        print('IBM WXS Client is installed successfully at the \
              following location :%s' % output)

if __name__ == '__main__':
    unittest.main()
